
# Enum: pv_formula_options


The formula used to generate the set of permissible values from the code_set values

URI: [linkml:pv_formula_options](https://w3id.org/linkml/pv_formula_options)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| CODE | The permissible values are the set of possible codes in the code set |  |  |
| CURIE | The permissible values are the set of CURIES in the code set |  |  |
| URI | The permissible values are the set of code URIs in the code set |  |  |
| FHIR_CODING | The permissible values are the set of FHIR coding elements derived from the code set |  |  |

